@@ -1,15 +1,7 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-
 import base64
 import hashlib
 import logging
 import os
-from builtins import object
-
-from past.utils import old_div
 
 from .item_uploader import ItemUploader
 from .util import deprecation
@@ -245,7 +237,7 @@ class DocumentUploader(object):
             # read the raw file content and encode it
             raw = open(filename, "rb").read()
             content = base64.b64encode(raw)
-            content_size = old_div(len(content), 1024 / 1024)
+            content_size = len(content) / 1024 / 1024
 
             # build a checksum over the original file content and use it as the
             # item identifier
