@@ -36,6 +36,7 @@ from .pipeline_workflows import PipelineWorkflowMixin
 from .project_translations import ProjectTranslationsMixin
 from .projects import ProjectsMixin
 from .savedsearches import SavedSearchesMixin
+from .smart_answers import SmartAnswersMixin
 from .smartfilters import SmartfiltersMixin
 from .sources import SourcesMixin
 from .subscriptions import SubscriptionsMixin
@@ -235,9 +236,13 @@ class TopicApiBaseMixin:
 
         :param project_id: Project identifier.
         :param query: Optional query to run.
-        :param query_context: Dictionary containing context of the query.
-            It includes terms that user typed in a searchbar (`searchbar_query`)
-            and dashboard filters (`dashboard_filters`).
+        :param query_context: Dictionary containing context of the query:
+
+                - `searchbar_query` : Terms that user typed in a searchbar.
+                - `dashboard_filters` : Additional filter-queries provided via dashboard or widget configuration.
+                - `like` : Additional input to perform approximate search on.
+                         For now `like` is considered to be a long string (e.g. paragraphs)
+
         :param start: Zero based starting point.
         :param count: Maximum number of items to return.
         :param child_count: Maximum number of entities to return with items.
@@ -259,6 +264,7 @@ class TopicApiBaseMixin:
                 - `update_cache` if `False` the result won't be cached. Used
                   for non-interactive queries that iterate over a large number
                   of items. Defaults to `True`.
+
         :param encrypted_query: Optional Encrypted query returned by
             `get_encrypted_query` method. This parameter overrides the `query`
             parameter and `query_template_params` (as part of `options`
@@ -1275,6 +1281,13 @@ class TopicApiBaseMixin:
         :param kwargs: Query parameters. All keyword arguments are passed on
             verbatim to the API. See the [[Items#Get Item|Get Item]] resource
             for all possible parameters.
+
+        :Keyword Arguments:
+            * *highlight_query* (``Union[str,dict]``) --
+                Can be a single query-string using squirro syntax.
+                OR a dictionary containing more metadata, currently supported keys are:
+                `highlight_query.query`: squirro query syntax
+                `highlight_query.like`: long piece of text to perform concept search on
         :returns: A dictionary which contains the individual item.
 
         Example::
@@ -1315,7 +1328,8 @@ class TopicApiBaseMixin:
             "project_id": project_id,
             "item_id": item_id,
         }
-
+        if isinstance(kwargs.get("highlight_query"), dict):
+            kwargs["highlight_query"] = json.dumps("highlight_query")
         res = self._perform_request("get", url, params=kwargs)
         return self._process_response(res)
 
@@ -1743,5 +1757,6 @@ class TopicApiMixin(
     MLPublishMixin,
     MLUserFeedbackMixin,
     MLSentenceSplitterMixin,
+    SmartAnswersMixin,
 ):
     pass
